@@ -1,14 +1,23 @@
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ Utility functions for working with Python Eggs. """
 
 
-# Standard library imports.
+# 3rd party imports.
 import pkg_resources
 
 # Enthought library imports.
 from traits.util.toposort import topological_sort
 
 
-def add_eggs_on_path(working_set, path):
+def add_eggs_on_path(working_set, path, on_error=None):
     """ Add all eggs found on the path to a working set. """
 
     environment = pkg_resources.Environment(path)
@@ -17,13 +26,15 @@ def add_eggs_on_path(working_set, path):
     # to the working set without version conflicts or missing requirements.
     distributions, errors = working_set.find_plugins(environment)
     if len(errors) > 0:
-        raise SystemError('Cannot find eggs %s' % errors)
+        if on_error:
+            on_error(errors)
+        else:
+            raise SystemError("Cannot find eggs %s" % errors)
 
     # Add the distributions to the working set (this makes any Python
     # modules in the eggs available for importing).
-    map(working_set.add, distributions)
-    
-    return
+    for distribution in distributions:
+        working_set.add(distribution)
 
 
 def get_entry_points_in_egg_order(working_set, entry_point_name):
@@ -40,8 +51,8 @@ def get_entry_points_in_egg_order(working_set, entry_point_name):
 
     entry_points = []
     for distribution in distributions:
-        map = distribution.get_entry_map(entry_point_name)
-        entry_points.extend(map.values())
+        entry_map = distribution.get_entry_map(entry_point_name)
+        entry_points.extend(list(entry_map.values()))
 
     return entry_points
 
@@ -91,5 +102,3 @@ def get_requires(working_set, distribution):
             requires.append(working_set.find(requirement))
 
     return requires
-
-#### EOF ######################################################################
