@@ -1,16 +1,18 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A trait type used to declare and access extension points. """
 
 
 # Standard library imports.
-import inspect, weakref
+import inspect
+import weakref
 
 # Enthought library imports.
 from traits.api import List, TraitType, Undefined, provides
@@ -19,51 +21,11 @@ from traits.api import List, TraitType, Undefined, provides
 from .i_extension_point import IExtensionPoint
 
 
-
-def contributes_to(id):
-    """ A factory for extension point decorators!
-
-    As an alternative to making contributions via traits, you can use this
-    decorator to mark any method on a 'Plugin' as contributing to an extension
-    point (note this is *only* used on 'Plugin' instances!).
-
-    e.g. Using a trait you might have something like::
-
-        class MyPlugin(Plugin):
-            messages = List(contributes_to='acme.messages')
-
-            def _messages_default(self):
-                return ['Hello', 'Hola']
-
-    whereas, using the decorator, it would be::
-
-        class MyPlugin(Plugin):
-            @contributes_to('acme.messages')
-            def _get_messages(self):
-                return ['Hello', 'Hola']
-
-    There is not much in it really, but the decorator version looks a little
-    less like 'magic' since it doesn't require the developer to know about
-    Traits default initializers. However, if you know that you will want to
-    dynamically change your contributions then use the trait version  because
-    all you have to do is change the value of the trait and the framework will
-    react accordingly.
-
-    """
-
-    def decorator(fn):
-        """ A decorator for marking methods as extension contributors. """
-
-        fn.__extension_point__ = id
-
-        return fn
-
-    return decorator
-
-
 # Exception message template.
-INVALID_TRAIT_TYPE = 'extension points must be "List"s e.g. List, List(Int)' \
-' but a value of %s was specified.'
+INVALID_TRAIT_TYPE = (
+    'extension points must be "List"s e.g. List, List(Int)'
+    " but a value of %s was specified."
+)
 
 
 # Even though trait types do not themselves have traits, we can still
@@ -96,8 +58,6 @@ class ExtensionPoint(TraitType):
         for trait_name, trait in obj.traits(__extension_point__=True).items():
             trait.trait_type.connect(obj, trait_name)
 
-        return
-
     @staticmethod
     def disconnect_extension_point_traits(obj):
         """ Disconnect all of the 'ExtensionPoint' traits on an object. """
@@ -105,8 +65,6 @@ class ExtensionPoint(TraitType):
         for trait_name, trait in obj.traits(__extension_point__=True).items():
             trait.trait_type.disconnect(obj, trait_name)
 
-        return
-
     ###########################################################################
     # 'object' interface.
     ###########################################################################
@@ -117,8 +75,8 @@ class ExtensionPoint(TraitType):
         # We add '__extension_point__' to the metadata to make the extension
         # point traits easier to find with the 'traits' and 'trait_names'
         # methods on 'HasTraits'.
-        metadata['__extension_point__'] = True
-        super(ExtensionPoint, self).__init__(**metadata)
+        metadata["__extension_point__"] = True
+        super().__init__(**metadata)
 
         # The trait type that describes the extension point.
         #
@@ -136,7 +94,7 @@ class ExtensionPoint(TraitType):
 
         # The Id of the extension point.
         if id is None:
-            raise ValueError('an extension point must have an Id')
+            raise ValueError("an extension point must have an Id")
 
         self.id = id
 
@@ -147,11 +105,9 @@ class ExtensionPoint(TraitType):
         # Dict(weakref.ref(Any), Dict(Str, Callable))
         self._obj_to_listeners_map = weakref.WeakKeyDictionary()
 
-        return
-
     def __repr__(self):
         """ String representation of an ExtensionPoint object """
-        return "ExtensionPoint(id={})".format(self.id)
+        return "ExtensionPoint(id={!r})".format(self.id)
 
     ###########################################################################
     # 'TraitType' interface.
@@ -178,8 +134,6 @@ class ExtensionPoint(TraitType):
         # for exxample ;^).
         extension_registry.set_extensions(self.id, value)
 
-        return
-
     ###########################################################################
     # 'ExtensionPoint' interface.
     ###########################################################################
@@ -201,20 +155,18 @@ class ExtensionPoint(TraitType):
 
             # If an index was specified then we fire an '_items' changed event.
             if event.index is not None:
-                name = trait_name + '_items'
-                old  = Undefined
-                new  = event
+                name = trait_name + "_items"
+                old = Undefined
+                new = event
 
             # Otherwise, we fire a normal trait changed event.
             else:
                 name = trait_name
-                old  = event.removed
-                new  = event.added
+                old = event.removed
+                new = event.added
 
             obj.trait_property_changed(name, old, new)
 
-            return
-
         extension_registry = self._get_extension_registry(obj)
 
         # Add the listener to the extension registry.
@@ -225,8 +177,6 @@ class ExtensionPoint(TraitType):
         listeners = self._obj_to_listeners_map.setdefault(obj, {})
         listeners[trait_name] = listener
 
-        return
-
     def disconnect(self, obj, trait_name):
         """ Disconnect the extension point from a trait on an object. """
 
@@ -242,8 +192,6 @@ class ExtensionPoint(TraitType):
             # Clean up.
             del self._obj_to_listeners_map[obj][trait_name]
 
-        return
-
     ###########################################################################
     # Private interface.
     ###########################################################################
@@ -251,15 +199,13 @@ class ExtensionPoint(TraitType):
     def _get_extension_registry(self, obj):
         """ Return the extension registry in effect for an object. """
 
-        extension_registry = getattr(obj, 'extension_registry', None)
+        extension_registry = getattr(obj, "extension_registry", None)
         if extension_registry is None:
             raise ValueError(
                 'The "ExtensionPoint" trait type can only be used in '
-                'objects that have a reference to an extension registry '
+                "objects that have a reference to an extension registry "
                 'via their "extension_registry" trait. '
-                'Extension point Id <%s>' % self.id
+                "Extension point Id <%s>" % self.id
             )
 
         return extension_registry
-
-#### EOF ######################################################################
