@@ -1,3 +1,12 @@
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ The interface for extension providers. """
 
 
@@ -5,7 +14,7 @@
 from traits.api import Event, Interface
 
 # Local imports.
-from extension_point_changed_event import ExtensionPointChangedEvent
+from .extension_point_changed_event import ExtensionPointChangedEvent
 
 
 class IExtensionProvider(Interface):
@@ -29,5 +38,3 @@ class IExtensionProvider(Interface):
         does not contribute any extensions to the extension point.
 
         """
-
-#### EOF ######################################################################
