@@ -1,15 +1,17 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The default implementation of the 'IPlugin' interface. """
 
 # Standard library imports.
-import inspect, logging, os
+import logging
+import os
 from os.path import exists, join
 
 # Enthought library imports.
@@ -42,42 +44,42 @@ class Plugin(ExtensionProvider):
 
     #### 'IPlugin' interface ##################################################
 
-    # The activator used to start and stop the plugin.
-    #
-    # By default the *same* activator instance is used for *all* plugins of
-    # this type.
+    #: The activator used to start and stop the plugin.
+    #:
+    #: By default the *same* activator instance is used for *all* plugins of
+    #: this type.
     activator = Instance(IPluginActivator, PluginActivator())
 
-    # The application that the plugin is part of.
+    #: The application that the plugin is part of.
     application = Instance(IApplication)
 
-    # The name of a directory (created for you) that the plugin can read and
-    # write to at will.
+    #: The name of a directory (created for you) that the plugin can read and
+    #: write to at will.
     home = Str
 
-    # The plugin's unique identifier.
-    #
-    # If no identifier is specified then the module and class name of the
-    # plugin are used to create an Id with the form 'module_name.class_name'.
+    #: The plugin's unique identifier.
+    #:
+    #: If no identifier is specified then the module and class name of the
+    #: plugin are used to create an Id with the form 'module_name.class_name'.
     id = Str
 
-    # The plugin's name (suitable for displaying to the user).
-    #
-    # If no name is specified then the plugin's class name is used with an
-    # attempt made to turn camel-case class names into words separated by
-    # spaces (e.g. if the class name is 'MyPlugin' then the name would be
-    # 'My Plugin'). Of course, if you really care about the actual name, then
-    # just set it!
+    #: The plugin's name (suitable for displaying to the user).
+    #:
+    #: If no name is specified then the plugin's class name is used with an
+    #: attempt made to turn camel-case class names into words separated by
+    #: spaces (e.g. if the class name is 'MyPlugin' then the name would be
+    #: 'My Plugin'). Of course, if you really care about the actual name, then
+    #: just set it!
     name = Str
 
     #### 'IExtensionPointUser' interface ######################################
 
-    # The extension registry that the object's extension points are stored in.
+    #: The extension registry that the object's extension points are stored in.
     extension_registry = Property(Instance(IExtensionRegistry))
 
     #### 'IServiceUser' interface #############################################
 
-    # The service registry that the object's services are stored in.
+    #: The service registry that the object's services are stored in.
     service_registry = Property(Instance(IServiceRegistry))
 
     #### Private interface ####################################################
@@ -112,7 +114,6 @@ class Plugin(ExtensionProvider):
 
         extension_points = [
             trait.trait_type
-
             for trait in self.traits(__extension_point__=True).values()
         ]
 
@@ -129,26 +130,8 @@ class Plugin(ExtensionProvider):
         # fine to allow mutiple traits!
         trait_names = self.trait_names(contributes_to=extension_point_id)
 
-        # FIXME: This is a temporary fix, which was necessary due to the
-        #        namespace refactor, but should be removed at some point.
         if len(trait_names) == 0:
-            old_id = 'enthought.' + extension_point_id
-            trait_names = self.trait_names(contributes_to=old_id)
-#            if trait_names:
-#                print 'deprecated:', old_id
-
-        if len(trait_names) == 0:
-            # If there is no contributing trait then look for any decorated
-            # methods.
-            extensions = self._harvest_methods(extension_point_id)
-
-            # FIXME: This is a temporary fix, which was necessary due to the
-            #        namespace refactor, but should be removed at some point.
-            if not extensions:
-                old_id = 'enthought.' + extension_point_id
-                extensions = self._harvest_methods(old_id)
-#                if extensions:
-#                    print 'deprecated:', old_id
+            extensions = []
 
         elif len(trait_names) == 1:
             extensions = self._get_extensions_from_trait(trait_names[0])
@@ -171,7 +154,7 @@ class Plugin(ExtensionProvider):
         # 'application.home'.
         #
         # i.e. .../my.application.id/plugins/
-        plugins_dir = join(self.application.home, 'plugins')
+        plugins_dir = join(self.application.home, "plugins")
         if not exists(plugins_dir):
             os.mkdir(plugins_dir)
 
@@ -185,8 +168,11 @@ class Plugin(ExtensionProvider):
     def _id_default(self):
         """ Trait initializer. """
 
-        id = '%s.%s' % (type(self).__module__, type(self).__name__)
-        logger.warning('plugin %s has no Id - using <%s>' % (self, id))
+        id = "%s.%s" % (type(self).__module__, type(self).__name__)
+        logger.warning(
+            "plugin {} has no Id - using <{}>".format(
+                object.__repr__(self), id)
+        )
 
         return id
 
@@ -194,7 +180,10 @@ class Plugin(ExtensionProvider):
         """ Trait initializer. """
 
         name = camel_case_to_words(type(self).__name__)
-        logger.warning('plugin %s has no name - using <%s>' % (self, name))
+        logger.warning(
+            "plugin {} has no name - using <{}>".format(
+                object.__repr__(self), name)
+        )
 
         return name
 
@@ -204,7 +193,7 @@ class Plugin(ExtensionProvider):
         """ Start the plugin.
 
         This method will *always* be empty so that you never have to call
-        'super(xxx, self).start()' if you provide an implementation in a
+        'super().start()' if you provide an implementation in a
         derived class.
 
         The framework does what it needs to do when it starts a plugin by means
@@ -218,7 +207,7 @@ class Plugin(ExtensionProvider):
         """ Stop the plugin.
 
         This method will *always* be empty so that you never have to call
-        'super(xxx, self).stop()' if you provide an implementation in a
+        'super().stop()' if you provide an implementation in a
         derived class.
 
         The framework does what it needs to do when it stops a plugin by means
@@ -242,25 +231,21 @@ class Plugin(ExtensionProvider):
 
         ExtensionPoint.connect_extension_point_traits(self)
 
-        return
-
     def disconnect_extension_point_traits(self):
         """ Disconnect all of the plugin's extension points."""
 
         ExtensionPoint.disconnect_extension_point_traits(self)
 
-        return
-
     def register_services(self):
         """ Register the services offered by the plugin. """
 
         for trait_name, trait in self.traits(service=True).items():
             logger.warning(
                 'DEPRECATED: Do not use the "service=True" metadata anymore. '
-                'Services should now be offered using the service '
-                'offer extension point (envisage.service_offers) '
-                'from the core plugin. '
-                'Plugin %s trait <%s>' % (self, trait_name)
+                "Services should now be offered using the service "
+                "offer extension point (envisage.service_offers) "
+                "from the core plugin. "
+                "Plugin %s trait <%s>" % (self, trait_name)
             )
 
             # Register a service factory for the trait.
@@ -270,8 +255,6 @@ class Plugin(ExtensionProvider):
             # service when the plugin is stopped.
             self._service_ids.append(service_id)
 
-        return
-
     def unregister_services(self):
         """ Unregister any service offered by the plugin. """
 
@@ -281,13 +264,17 @@ class Plugin(ExtensionProvider):
         service_ids.reverse()
 
         for service_id in service_ids:
-            self.application.unregister_service(service_id)
+            try:
+                self.application.get_service_from_id(service_id)
+            except ValueError:
+                # the service may have already been individually unregistered
+                pass
+            else:
+                self.application.unregister_service(service_id)
 
         # Just in case the plugin is started again!
         self._service_ids = []
 
-        return
-
     ###########################################################################
     # Private interface.
     ###########################################################################
@@ -299,38 +286,35 @@ class Plugin(ExtensionProvider):
 
         # Ignore the '_items' part of the trait name (if it is there!), and get
         # the actual trait.
-        base_trait_name = trait_name.split('_items')[0]
-        trait           = self.trait(base_trait_name)
+        base_trait_name = trait_name.split("_items")[0]
+        trait = self.trait(base_trait_name)
 
         # If the trait is one that contributes to an extension point then fire
         # an appropriate 'extension point changed' event.
         if trait.contributes_to is not None:
-            if trait_name.endswith('_items'):
-                added   = new.added
+            if trait_name.endswith("_items"):
+                added = new.added
                 removed = new.removed
-                index   = new.index
+                index = new.index
 
             else:
-                added   = new
+                added = new
                 removed = old
-                index   = slice(0, max(len(old), len(new)))
+                index = slice(0, len(old))
 
             # Let the extension registry know about the change.
             self._fire_extension_point_changed(
                 trait.contributes_to, added, removed, index
             )
 
-        return
-
     #### Methods ##############################################################
 
     def _create_multiple_traits_exception(self, extension_point_id):
         """ Create the exception raised when multiple traits are found. """
 
         exception = ValueError(
-            'multiple traits for extension point <%s> in plugin <%s>' % (
-                extension_point_id, self.id
-            )
+            "multiple traits for extension point <%s> in plugin <%s>"
+            % (extension_point_id, self.id)
         )
 
         return exception
@@ -341,9 +325,9 @@ class Plugin(ExtensionProvider):
         try:
             extensions = getattr(self, trait_name)
 
-        except:
+        except Exception:
             logger.exception(
-                'getting extensions from %s, trait <%s>' % (self, trait_name)
+                "getting extensions from %s, trait <%s>" % (self, trait_name)
             )
             raise
 
@@ -360,7 +344,7 @@ class Plugin(ExtensionProvider):
         # trait.
         #
         # fixme: This works for 'Instance' traits, but what about 'AdaptsTo'
-        # and 'AdaptedTo' traits?
+        # and 'Supports' traits?
         else:
             # Note that in traits the protocol can be an actual class or
             # interfacem or the *name* of a class or interface. This allows
@@ -369,46 +353,6 @@ class Plugin(ExtensionProvider):
 
         return protocol
 
-    def _harvest_methods(self, extension_point_id):
-        """ Harvest all method-based contributions. """
-
-        extensions = []
-        # Using inspect.getmembers(self) here will cause an infinite recursion,
-        # so use an internal HasTraits method for inspecting the MRO of the
-        # instance's type to find all methods instead.
-        for name in self._each_trait_method(self):
-            value = getattr(self, name)
-            if self._is_extension_method(value, extension_point_id):
-                result = value()
-                if not isinstance(result, list):
-                    result = [result]
-
-                extensions.extend(result)
-
-        return extensions
-
-    def _is_extension_method(self, value, extension_point_id):
-        """ Return True if the value is an extension method.
-
-        i.e. If the method is one that makes a contribution to the extension
-        point. Currently there is exactly one way to make a method make a
-        contribution, and that is to mark it using the 'contributes_to'
-        decorator, e.g::
-
-          @contributes_to('acme.motd.messages')
-          def get_messages(self):
-              ...
-              messages = [...]
-              ...
-              return messages
-
-        """
-
-        is_extension_method = inspect.ismethod(value) \
-            and extension_point_id == getattr(value,'__extension_point__',None)
-
-        return is_extension_method
-
     def _register_service_factory(self, trait_name, trait):
         """ Register a service factory for the specified trait. """
 
@@ -426,4 +370,10 @@ class Plugin(ExtensionProvider):
 
         return self.application.register_service(protocol, factory)
 
-#### EOF ######################################################################
+    ###########################################################################
+    # 'object' interface.
+    ###########################################################################
+
+    def __repr__(self):
+        """ String representation of a Plugin object """
+        return "Plugin(id={!r}, name={!r})".format(self.id, self.name)
