@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A plugin event. """
 
@@ -17,6 +18,4 @@ class PluginEvent(Vetoable):
     """ A plugin event. """
 
     # The plugin that the event is for.
-    plugin = Instance('envisage.api.IPlugin')
-
-#### EOF ######################################################################
+    plugin = Instance("envisage.api.IPlugin")
