@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 from pyface.tasks.action.api import TaskAction
 from traits.api import Instance
@@ -16,9 +17,9 @@ class StartQtConsoleAction(TaskAction):
     """ Open in a separate window a Qt console attached to a, existing kernel.
     """
 
-    id = 'ipython_qtconsole'
+    id = "ipython_qtconsole"
 
-    name = 'IPython Console'
+    name = "IPython Console"
 
     kernel = Instance(InternalIPKernel)
 
