@@ -1,24 +1,32 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A view containing the contents of a Python shell namespace. """
 
-import types
-
 # Enthought library imports.
 
 from envisage.plugins.python_shell.api import IPythonShell
-from envisage.plugins.python_shell.view.python_shell_view import PythonShellView
+from envisage.plugins.python_shell.view.python_shell_view import (
+    PythonShellView,
+)
 
 from pyface.workbench.api import View
 
-from traits.api import HasTraits, Str, Property, List, Instance, \
-        DelegatesTo, cached_property
+from traits.api import (
+    HasTraits,
+    Str,
+    Property,
+    List,
+    Instance,
+    DelegatesTo,
+    cached_property,
+)
 
 from traitsui.api import Item, TableEditor, VGroup
 from traitsui.api import View as TraitsView
@@ -33,17 +41,17 @@ from traitsui.table_filter import RuleFilterTemplate
 filters = [EvalFilterTemplate, MenuFilterTemplate, RuleFilterTemplate]
 
 table_editor = TableEditor(
-    columns     = [
-        ObjectColumn(name='name'),
-        ObjectColumn(name='type'),
-        ObjectColumn(name='module'),
+    columns=[
+        ObjectColumn(name="name"),
+        ObjectColumn(name="type"),
+        ObjectColumn(name="module"),
     ],
-    editable    = False,
-    deletable   = False,
-    sortable    = True,
-    sort_model  = False,
-    filters     = filters,
-    search      = RuleTableFilter(),
+    editable=False,
+    deletable=False,
+    sortable=True,
+    sort_model=False,
+    filters=filters,
+    search=RuleTableFilter(),
 )
 
 
@@ -52,13 +60,13 @@ def type_to_str(obj):
     Make a string out `obj`'s type robustly.
     """
     typ = type(obj)
-    if typ.__name__ == 'vtkobject' or typ is types.InstanceType:
+    if typ.__name__ == "vtkobject":
         typ = obj.__class__
-    if type.__module__ == '__builtin__':
+    if type.__module__ == "__builtin__":
         # Make things like int and str easier to read.
         return typ.__name__
     else:
-        name = '%s.%s' % (typ.__module__, typ.__name__)
+        name = "%s.%s" % (typ.__module__, typ.__name__)
         return name
 
 
@@ -67,10 +75,10 @@ def module_to_str(obj):
     Return the string representation of *obj*'s ``__module__`` attribute, or
     an empty string if there is no such attribute.
     """
-    if hasattr(obj, '__module__'):
+    if hasattr(obj, "__module__"):
         return str(obj.__module__)
     else:
-        return ''
+        return ""
 
 
 class NamespaceView(View):
@@ -79,41 +87,39 @@ class NamespaceView(View):
     #### 'IView' interface ####################################################
 
     # The part's globally unique identifier.
-    id = 'enthought.plugins.python_shell.view.namespace_view'
+    id = "enthought.plugins.python_shell.view.namespace_view"
 
     # The view's name.
-    name = 'Namespace'
+    name = "Namespace"
 
     # The default position of the view relative to the item specified in the
     # 'relative_to' trait.
-    position = 'left'
+    position = "left"
 
     #### 'NamespaceView' interface ############################################
 
     # The bindings in the namespace.  This is a list of HasTraits objects with
     # 'name', 'type' and 'module' string attributes.
-    bindings = Property(List, depends_on=['namespace'])
+    bindings = Property(List, observe="namespace")
 
     shell_view = Instance(PythonShellView)
 
-    namespace = DelegatesTo('shell_view')
-
+    namespace = DelegatesTo("shell_view")
 
     # The default traits UI view.
     traits_view = TraitsView(
         VGroup(
             Item(
-                'bindings',
-                id     = 'table',
-                editor = table_editor,
-                springy = True,
-                resizable = True,
+                "bindings",
+                id="table",
+                editor=table_editor,
+                springy=True,
+                resizable=True,
             ),
-
-            show_border = True,
-            show_labels = False
+            show_border=True,
+            show_labels=False,
         ),
-        resizable = True,
+        resizable=True,
     )
 
     ###########################################################################
@@ -127,11 +133,11 @@ class NamespaceView(View):
 
         """
 
-        self.ui = self.edit_traits(parent=parent, kind='subpanel')
+        self.ui = self.edit_traits(parent=parent, kind="subpanel")
 
         self.shell_view = self.window.application.get_service(IPythonShell)
-        # 'shell_view' is an instance of the class PythonShellView from the module
-        # envisage.plugins.python_shell.view.python_shell_view.
+        # 'shell_view' is an instance of the class PythonShellView from the
+        # module envisage.plugins.python_shell.view.python_shell_view.
 
         return self.ui.control
 
@@ -153,7 +159,11 @@ class NamespaceView(View):
             type = Str
             module = Str
 
-        data = [item(name=name, type=type_to_str(value), module=module_to_str(value))
-                    for name, value in self.shell_view.namespace.items()]
+        data = [
+            item(
+                name=name, type=type_to_str(value), module=module_to_str(value)
+            )
+            for name, value in self.shell_view.namespace.items()
+        ]
 
         return data
