@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ A text editor. """
 
@@ -15,7 +16,7 @@ from os.path import basename
 # Enthought library imports.
 from pyface.workbench.api import TraitsUIEditor
 from pyface.api import FileDialog, CANCEL
-from traits.api import Code, Instance
+from traits.api import Code, Instance, observe
 from traitsui.api import CodeEditor, Group, Item, View
 from traitsui.key_bindings import KeyBinding, KeyBindings
 from traitsui.menu import NoButtons
@@ -29,10 +30,9 @@ def _id_generator():
 
     i = 1
     while True:
-        yield(i)
+        yield (i)
         i += 1
 
-    return
 
 _id_generator = _id_generator()
 
@@ -60,27 +60,24 @@ class TextEditor(TraitsUIEditor):
             self.save_as()
 
         else:
-            f = open(self.obj.path, 'w')
-            f.write(self.text)
-            f.close()
+            with open(self.obj.path, "w", encoding="utf-8") as f:
+                f.write(self.text)
 
             # We have just saved the file so we ain't dirty no more!
             self.dirty = False
 
-        return
-
     def save_as(self):
         """ Saves the text to disk after prompting for the file name. """
 
         dialog = FileDialog(
-            parent           = self.window.control,
-            action           = 'save as',
-            default_filename = self.name,
-            wildcard         = FileDialog.WILDCARD_PY
+            parent=self.window.control,
+            action="save as",
+            default_filename=self.name,
+            wildcard=FileDialog.WILDCARD_PY,
         )
         if dialog.open() != CANCEL:
             # Update the editor.
-            self.id   = dialog.path
+            self.id = dialog.path
             self.name = basename(dialog.path)
 
             # Update the resource.
@@ -89,8 +86,6 @@ class TextEditor(TraitsUIEditor):
             # Save it!
             self.save()
 
-        return
-
     ###########################################################################
     # 'TraitsUIEditor' interface.
     ###########################################################################
@@ -99,7 +94,7 @@ class TextEditor(TraitsUIEditor):
         """ Creates the traits UI that represents the editor. """
 
         ui = self.edit_traits(
-            parent=parent, view=self._create_traits_ui_view(), kind='subpanel'
+            parent=parent, view=self._create_traits_ui_view(), kind="subpanel"
         )
 
         return ui
@@ -117,7 +112,7 @@ class TextEditor(TraitsUIEditor):
         # Execute the code.
         if len(self.obj.path) > 0:
             view = self.window.get_view_by_id(
-                'envisage.plugins.python_shell_view'
+                "envisage.plugins.python_shell_view"
             )
 
             if view is not None:
@@ -125,15 +120,11 @@ class TextEditor(TraitsUIEditor):
                     'exec(open(r"%s").read())' % self.obj.path, hidden=False
                 )
 
-        return
-
     def select_line(self, lineno):
         """ Selects the specified line. """
 
         self.ui.info.text.selected_line = lineno
 
-        return
-
     ###########################################################################
     # Private interface.
     ###########################################################################
@@ -145,61 +136,56 @@ class TextEditor(TraitsUIEditor):
 
         key_bindings = KeyBindings(
             KeyBinding(
-                binding1    = 'Ctrl-s',
-                description = 'Save the file',
-                method_name = 'save'
+                binding1="Ctrl-s",
+                description="Save the file",
+                method_name="save",
             ),
-
             KeyBinding(
-                binding1    = 'Ctrl-r',
-                description = 'Run the file',
-                method_name = 'run'
-            )
+                binding1="Ctrl-r",
+                description="Run the file",
+                method_name="run",
+            ),
         )
 
         return key_bindings
 
     #### Trait change handlers ################################################
 
-    def _obj_changed(self, new):
+    @observe("obj")
+    def _handle_update_to_object(self, event):
         """ Static trait change handler. """
-
+        new = event.new
         # The path will be the empty string if we are editing a file that has
         # not yet been saved.
         if len(new.path) == 0:
-            self.id   = self._get_unique_id()
+            self.id = self._get_unique_id()
             self.name = self.id
 
         else:
-            self.id   = new.path
+            self.id = new.path
             self.name = basename(new.path)
 
-            f = open(new.path, 'r')
-            self.text = f.read()
-            f.close()
+            with open(new.path, "r", encoding="utf-8") as f:
+                self.text = f.read()
 
-        return
-
-    def _text_changed(self, trait_name, old, new):
+    @observe("text")
+    def _update_dirty(self, event):
         """ Static trait change handler. """
 
         if self.traits_inited():
             self.dirty = True
 
-        return
-
-    def _dirty_changed(self, dirty):
+    @observe("dirty")
+    def _update_name(self, event):
         """ Static trait change handler. """
-
+        dirty = event.new
         if len(self.obj.path) > 0:
             if dirty:
-                self.name = basename(self.obj.path) + '*'
+                self.name = basename(self.obj.path) + "*"
 
             else:
                 self.name = basename(self.obj.path)
 
-        return
-
     #### Methods ##############################################################
 
     def _create_traits_ui_view(self):
@@ -214,23 +200,22 @@ class TextEditor(TraitsUIEditor):
         view = View(
             Group(
                 Item(
-                    'text', editor=CodeEditor(key_bindings=self.key_bindings)
+                    "text", editor=CodeEditor(key_bindings=self.key_bindings)
                 ),
-                show_labels = False
+                show_labels=False,
             ),
-
-            id        = 'envisage.editor.text_editor',
-            handler   = TextEditorHandler(),
-            kind      = 'live',
-            resizable = True,
-            width     = 1.0,
-            height    = 1.0,
-            buttons   = NoButtons,
+            id="envisage.editor.text_editor",
+            handler=TextEditorHandler(),
+            kind="live",
+            resizable=True,
+            width=1.0,
+            height=1.0,
+            buttons=NoButtons,
         )
 
         return view
 
-    def _get_unique_id(self, prefix='Untitled '):
+    def _get_unique_id(self, prefix="Untitled "):
         """ Return a unique id for a new file. """
 
         id = prefix + str(next(_id_generator))
@@ -238,5 +223,3 @@ class TextEditor(TraitsUIEditor):
             id = prefix + str(next(_id_generator))
 
         return id
-
-#### EOF ######################################################################
