@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ An extension registry implementation with multiple providers. """
 
@@ -41,7 +42,7 @@ class ProviderExtensionRegistry(ExtensionRegistry):
     def set_extensions(self, extension_point_id, extensions):
         """ Set the extensions to an extension point. """
 
-        raise SystemError('extension points cannot be set')
+        raise SystemError("extension points cannot be set")
 
     ###########################################################################
     # 'ProviderExtensionRegistry' interface.
@@ -55,8 +56,6 @@ class ProviderExtensionRegistry(ExtensionRegistry):
         for extension_point_id, (refs, added, index) in events.items():
             self._call_listeners(refs, extension_point_id, added, [], index)
 
-        return
-
     def get_providers(self):
         """ Return all of the providers in the registry. """
 
@@ -74,8 +73,6 @@ class ProviderExtensionRegistry(ExtensionRegistry):
         for extension_point_id, (refs, removed, index) in events.items():
             self._call_listeners(refs, extension_point_id, [], removed, index)
 
-        return
-
     ###########################################################################
     # Protected 'ExtensionRegistry' interface.
     ###########################################################################
@@ -85,9 +82,9 @@ class ProviderExtensionRegistry(ExtensionRegistry):
 
         # If we don't know about the extension point then it sure ain't got
         # any extensions!
-        if not extension_point_id in self._extension_points:
+        if extension_point_id not in self._extension_points:
             logger.warning(
-                'getting extensions of unknown extension point <%s>' \
+                "getting extensions of unknown extension point <%s>"
                 % extension_point_id
             )
             extensions = []
@@ -153,7 +150,7 @@ class ProviderExtensionRegistry(ExtensionRegistry):
             # provider contributes any extensions.
             if len(new) > 0:
                 index = sum(map(len, extensions))
-                refs  = self._get_listener_refs(extension_point_id)
+                refs = self._get_listener_refs(extension_point_id)
                 events[extension_point_id] = (refs, new[:], index)
 
             extensions.append(new)
@@ -166,8 +163,6 @@ class ProviderExtensionRegistry(ExtensionRegistry):
         for extension_point in provider.get_extension_points():
             self._extension_points[extension_point.id] = extension_point
 
-        return
-
     def _remove_provider(self, provider):
         """ Remove a provider. """
 
@@ -203,7 +198,7 @@ class ProviderExtensionRegistry(ExtensionRegistry):
             # provider contributed any extensions.
             if len(old) > 0:
                 offset = sum(map(len, extensions[:index]))
-                refs  = self._get_listener_refs(extension_point_id)
+                refs = self._get_listener_refs(extension_point_id)
                 events[extension_point_id] = (refs, old[:], offset)
 
             del extensions[index]
@@ -217,19 +212,17 @@ class ProviderExtensionRegistry(ExtensionRegistry):
             # Remove the extension point.
             del self._extension_points[extension_point.id]
 
-        return
-
     ###########################################################################
     # Private interface.
     ###########################################################################
 
     #### Trait change handlers ################################################
 
-    @on_trait_change('_providers:extension_point_changed')
+    @on_trait_change("_providers:extension_point_changed")
     def _providers_extension_point_changed(self, obj, trait_name, old, event):
         """ Dynamic trait change handler. """
 
-        logger.debug('provider <%s> extension point changed', obj)
+        logger.debug("provider <%s> extension point changed", obj)
 
         extension_point_id = event.extension_point_id
 
@@ -239,7 +232,7 @@ class ProviderExtensionRegistry(ExtensionRegistry):
         # This is because we only access extension points lazily and so we
         # can't tell what has actually changed because we have nothing to
         # compare it to!
-        if not extension_point_id in self._extensions:
+        if extension_point_id not in self._extensions:
             return
 
         # This is a list of lists where each inner list contains the
@@ -274,8 +267,6 @@ class ProviderExtensionRegistry(ExtensionRegistry):
             refs, extension_point_id, event.added, event.removed, index
         )
 
-        return
-
     #### Methods ##############################################################
 
     def _initialize_extensions(self, extension_point_id):
@@ -287,7 +278,7 @@ class ProviderExtensionRegistry(ExtensionRegistry):
         for provider in self._providers:
             extensions.append(provider.get_extensions(extension_point_id)[:])
 
-        logger.debug('extensions to <%s> <%s>', extension_point_id, extensions)
+        logger.debug("extensions to <%s> <%s>", extension_point_id, extensions)
 
         return extensions
 
@@ -295,11 +286,11 @@ class ProviderExtensionRegistry(ExtensionRegistry):
         """ Translate an event index by the given offset. """
 
         if isinstance(index, slice):
-            index = slice(index.start+offset, index.stop+offset, index.step)
+            index = slice(
+                index.start + offset, index.stop + offset, index.step
+            )
 
         else:
             index = index + offset
 
         return index
-
-#### EOF ######################################################################
