@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The service registry. """
 
@@ -18,7 +19,6 @@ from traits.api import Dict, Event, HasTraits, Int, provides
 # Local imports.
 from .i_service_registry import IServiceRegistry
 from .import_manager import ImportManager
-from ._compat import STRING_BASE_CLASS
 
 
 # Logging.
@@ -35,10 +35,10 @@ class ServiceRegistry(HasTraits):
 
     ####  IServiceRegistry interface ##########################################
 
-    # An event that is fired when a service is registered.
+    #: An event that is fired when a service is registered.
     registered = Event
 
-    # An event that is fired when a service is unregistered.
+    #: An event that is fired when a service is unregistered.
     unregistered = Event
 
     ####  Private interface ###################################################
@@ -66,7 +66,9 @@ class ServiceRegistry(HasTraits):
     # 'IServiceRegistry' interface.
     ###########################################################################
 
-    def get_required_service(self, protocol, query='', minimize='',maximize=''):
+    def get_required_service(
+        self, protocol, query="", minimize="", maximize=""
+    ):
         """ Return the service that matches the specified query.
 
         Raise a 'NoSuchServiceError' exception if no such service exists.
@@ -79,7 +81,7 @@ class ServiceRegistry(HasTraits):
 
         return service
 
-    def get_service(self, protocol, query='', minimize='', maximize=''):
+    def get_service(self, protocol, query="", minimize="", maximize=""):
         """ Return at most one service that matches the specified query. """
 
         services = self.get_services(protocol, query, minimize, maximize)
@@ -98,18 +100,18 @@ class ServiceRegistry(HasTraits):
             protocol, obj, properties = self._services[service_id]
 
         except KeyError:
-            raise ValueError('no service with id <%d>' % service_id)
+            raise ValueError("no service with id <%d>" % service_id)
 
         return obj
 
-    def get_services(self, protocol, query='', minimize='', maximize=''):
+    def get_services(self, protocol, query="", minimize="", maximize=""):
         """ Return all services that match the specified query. """
 
         services = []
         for service_id, (name, obj, properties) in self._services.items():
             if self._get_protocol_name(protocol) == name:
                 # If the protocol is a string then we need to import it!
-                if isinstance(protocol, STRING_BASE_CLASS):
+                if isinstance(protocol, str):
                     actual_protocol = ImportManager().import_symbol(protocol)
 
                 # Otherwise, it is an actual protocol, so just use it!
@@ -129,10 +131,10 @@ class ServiceRegistry(HasTraits):
 
         # Are we minimizing or maximising anything? If so then sort the list
         # of services by the specified attribute/property.
-        if minimize != '':
+        if minimize != "":
             services.sort(key=lambda x: getattr(x, minimize))
 
-        elif maximize != '':
+        elif maximize != "":
             services.sort(key=lambda x: getattr(x, maximize), reverse=True)
 
         return services
@@ -145,7 +147,7 @@ class ServiceRegistry(HasTraits):
             properties = properties.copy()
 
         except KeyError:
-            raise ValueError('no service with id <%d>' % service_id)
+            raise ValueError("no service with id <%d>" % service_id)
 
         return properties
 
@@ -162,7 +164,7 @@ class ServiceRegistry(HasTraits):
         self._services[service_id] = (protocol_name, obj, properties)
         self.registered = service_id
 
-        logger.debug('service <%d> registered %s', service_id, protocol_name)
+        logger.debug("service <%d> registered %s", service_id, protocol_name)
 
         return service_id
 
@@ -174,9 +176,7 @@ class ServiceRegistry(HasTraits):
             self._services[service_id] = protocol, obj, properties.copy()
 
         except KeyError:
-            raise ValueError('no service with id <%d>' % service_id)
-
-        return
+            raise ValueError("no service with id <%d>" % service_id)
 
     def unregister_service(self, service_id):
         """ Unregister a service. """
@@ -185,12 +185,10 @@ class ServiceRegistry(HasTraits):
             protocol, obj, properties = self._services.pop(service_id)
             self.unregistered = service_id
 
-            logger.debug('service <%d> unregistered', service_id)
+            logger.debug("service <%d> unregistered", service_id)
 
         except KeyError:
-            raise ValueError('no service with id <%d>' % service_id)
-
-        return
+            raise ValueError("no service with id <%d>" % service_id)
 
     ###########################################################################
     # Private interface.
@@ -216,7 +214,7 @@ class ServiceRegistry(HasTraits):
         try:
             result = eval(query, namespace)
 
-        except:
+        except Exception:
             result = False
 
         return result
@@ -224,12 +222,13 @@ class ServiceRegistry(HasTraits):
     def _get_protocol_name(self, protocol_or_name):
         """ Returns the full class name for a protocol. """
 
-        if isinstance(protocol_or_name, STRING_BASE_CLASS):
+        if isinstance(protocol_or_name, str):
             name = protocol_or_name
 
         else:
-            name = '%s.%s' % (
-                protocol_or_name.__module__, protocol_or_name.__name__
+            name = "%s.%s" % (
+                protocol_or_name.__module__,
+                protocol_or_name.__name__,
             )
 
         return name
@@ -260,7 +259,7 @@ class ServiceRegistry(HasTraits):
             # dictionary of properties that were registered with the service.
             #
             # If the factory is specified as a symbol path then import it.
-            if isinstance(obj, STRING_BASE_CLASS):
+            if isinstance(obj, str):
                 obj = ImportManager().import_symbol(obj)
 
             obj = obj(**properties)
@@ -271,5 +270,3 @@ class ServiceRegistry(HasTraits):
             self._services[service_id] = (name, obj, properties)
 
         return obj
-
-#### EOF ######################################################################
