@@ -1,3 +1,12 @@
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ The 'Foo' plugin """
 
 
@@ -12,7 +21,7 @@ class FooPlugin(Plugin):
     #### 'IPlugin' interface ##################################################
 
     # The plugin's unique identifier.
-    id = 'acme.foo'
+    id = "acme.foo"
 
     #### 'FooPlugin' interface ################################################
 
@@ -29,14 +38,8 @@ class FooPlugin(Plugin):
         self.started = True
         self.stopped = False
 
-        return
-
     def stop(self):
         """ Stop the plugin. """
 
         self.started = False
         self.stopped = True
-
-        return
-
-#### EOF ######################################################################
