@@ -1,16 +1,18 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ Used to track events in tests. """
 
 
 # Enthought library imports.
 from traits.api import HasTraits, List, Str, Tuple
+from traits.has_traits import observe
 
 
 class EventTracker(HasTraits):
@@ -45,19 +47,18 @@ class EventTracker(HasTraits):
 
     #### Trait change handlers ################################################
 
-    def _subscriptions_changed(self, old, new):
+    @observe("subscriptions")
+    def _update_listeners_on_all_subscriptions(self, event):
         """ Static trait change handler. """
-
+        old, new = event.old, event.new
         for subscription in old:
             self._remove_subscription(subscription)
 
         for subscription in new:
             self._add_subscription(subscription)
 
-
-        return
-
-    def _subscriptions_items_changed(self, event):
+    @observe("subscriptions:items")
+    def _update_listeners_on_changed_subscriptions(self, event):
         """ Static trait change handler. """
 
         for subscription in event.removed:
@@ -66,17 +67,12 @@ class EventTracker(HasTraits):
         for subscription in event.added:
             self._add_subscription(subscription)
 
-
-        return
-
     def _listener(self, obj, trait_name, old, new):
         """ Dynamic trait change listener. """
 
         self.events.append((obj, trait_name, old, new))
         self.event_names.append(trait_name)
 
-        return
-
     #### Methods ##############################################################
 
     def _add_subscription(self, subscription):
@@ -90,8 +86,6 @@ class EventTracker(HasTraits):
         else:
             obj.on_trait_change(self._listener)
 
-        return
-
     def _remove_subscription(self, subscription):
         """ Remove a subscription. """
 
@@ -102,7 +96,3 @@ class EventTracker(HasTraits):
 
         else:
             obj.on_trait_change(self._listener, remove=True)
-
-        return
-
-#### EOF ######################################################################
