@@ -1,15 +1,15 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ Tests for the provider extension registry. """
 
-
-# Standard imports
+# Standard library imports.
 import unittest
 
 # Enthought library imports.
@@ -18,10 +18,13 @@ from envisage.api import ProviderExtensionRegistry
 from traits.api import Int, List
 
 # Local imports.
-from .test_extension_registry import ExtensionRegistryTestCase
+from envisage.tests.test_extension_registry_mixin import (
+    ExtensionRegistryTestMixin
+)
 
 
-class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
+class ProviderExtensionRegistryTestCase(
+        ExtensionRegistryTestMixin, unittest.TestCase):
     """ Tests for the provider extension registry. """
 
     def setUp(self):
@@ -41,14 +44,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'x')]
+                return [ExtensionPoint(List, "x")]
 
             def get_extensions(self, extension_point):
                 """ Return the provider's contributions to an extension point.
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     extensions = [42, 43]
 
                 else:
@@ -64,7 +67,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     extensions = [44, 45, 46]
 
                 else:
@@ -75,21 +78,20 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         class ProviderC(ExtensionProvider):
             """ An empty provider! """
 
-
         # Add the providers to the registry.
         registry.add_provider(ProviderA())
         registry.add_provider(ProviderB())
         registry.add_provider(ProviderC())
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(5, len(extensions))
         self.assertEqual(list(range(42, 47)), extensions)
 
         # Make sure there's one and only one extension point.
         extension_points = registry.get_extension_points()
         self.assertEqual(1, len(extension_points))
-        self.assertEqual('x', extension_points[0].id)
+        self.assertEqual("x", extension_points[0].id)
 
     def test_provider_extensions_changed(self):
         """ provider extensions changed """
@@ -105,14 +107,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'my.ep')]
+                return [ExtensionPoint(List, "my.ep")]
 
             def get_extensions(self, extension_point_id):
                 """ Return the provider's contributions to an extension point.
 
                 """
 
-                if extension_point_id == 'my.ep':
+                if extension_point_id == "my.ep":
                     return self.x
 
                 else:
@@ -124,17 +126,16 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'my.ep', new, old, slice(0, len(old))
+                    "my.ep", new, old, slice(0, len(old))
                 )
 
             def _x_items_changed(self, event):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'my.ep', event.added, event.removed, event.index
+                    "my.ep", event.added, event.removed, event.index
                 )
 
-
         class ProviderB(ExtensionProvider):
             """ An extension provider. """
 
@@ -145,7 +146,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
 
                 """
 
-                if extension_point_id == 'my.ep':
+                if extension_point_id == "my.ep":
                     return self.x
 
                 else:
@@ -157,14 +158,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'my.ep', new, old, slice(0, len(old))
+                    "my.ep", new, old, slice(0, len(old))
                 )
 
             def _x_items_changed(self, event):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'my.ep', event.added, event.removed, event.index
+                    "my.ep", event.added, event.removed, event.index
                 )
 
         # Add the providers to the registry.
@@ -174,7 +175,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.add_provider(b)
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('my.ep')
+        extensions = registry.get_extensions("my.ep")
         self.assertEqual(3, len(extensions))
         self.assertEqual([42, 99, 100], extensions)
 
@@ -188,19 +189,19 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             listener.removed = event.removed
             listener.index = event.index
 
-        registry.add_extension_point_listener(listener, 'my.ep')
+        registry.add_extension_point_listener(listener, "my.ep")
 
         # Add a new extension via the provider.
         a.x.append(43)
 
         # Make sure the listener got called.
-        self.assertEqual('my.ep', listener.extension_point)
+        self.assertEqual("my.ep", listener.extension_point)
         self.assertEqual([43], listener.added)
         self.assertEqual([], listener.removed)
         self.assertEqual(1, listener.index)
 
         # Now we should get the new extension.
-        extensions = registry.get_extensions('my.ep')
+        extensions = registry.get_extensions("my.ep")
         self.assertEqual(4, len(extensions))
         self.assertEqual([42, 43, 99, 100], extensions)
 
@@ -208,13 +209,13 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         b.x.insert(0, 98)
 
         # Make sure the listener got called.
-        self.assertEqual('my.ep', listener.extension_point)
+        self.assertEqual("my.ep", listener.extension_point)
         self.assertEqual([98], listener.added)
         self.assertEqual([], listener.removed)
         self.assertEqual(2, listener.index)
 
         # Now we should get the new extension.
-        extensions = registry.get_extensions('my.ep')
+        extensions = registry.get_extensions("my.ep")
         self.assertEqual(5, len(extensions))
         self.assertEqual([42, 43, 98, 99, 100], extensions)
 
@@ -222,14 +223,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         b.x = [1, 2]
 
         # Make sure the listener got called.
-        self.assertEqual('my.ep', listener.extension_point)
+        self.assertEqual("my.ep", listener.extension_point)
         self.assertEqual([1, 2], listener.added)
         self.assertEqual([98, 99, 100], listener.removed)
         self.assertEqual(2, listener.index.start)
         self.assertEqual(5, listener.index.stop)
 
         # Now we should get the new extension.
-        extensions = registry.get_extensions('my.ep')
+        extensions = registry.get_extensions("my.ep")
         self.assertEqual(4, len(extensions))
         self.assertEqual([42, 43, 1, 2], extensions)
 
@@ -245,14 +246,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'x')]
+                return [ExtensionPoint(List, "x")]
 
             def get_extensions(self, extension_point):
                 """ Return the provider's contributions to an extension point.
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     return [42]
 
                 else:
@@ -264,14 +265,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'x', event.added, event.removed, event.index
+                    "x", event.added, event.removed, event.index
                 )
 
         # Add the provider to the registry.
         registry.add_provider(ProviderA())
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(1, len(extensions))
         self.assertTrue(42 in extensions)
 
@@ -285,7 +286,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             listener.removed = event.removed
             listener.index = event.index
 
-        registry.add_extension_point_listener(listener, 'x')
+        registry.add_extension_point_listener(listener, "x")
 
         # Add a new provider.
         class ProviderB(ExtensionProvider):
@@ -296,7 +297,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     extensions = [43, 44]
 
                 else:
@@ -307,12 +308,12 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.add_provider(ProviderB())
 
         # Make sure the listener got called.
-        self.assertEqual('x', listener.extension_point)
+        self.assertEqual("x", listener.extension_point)
         self.assertEqual([43, 44], listener.added)
         self.assertEqual([], listener.removed)
 
         # Now we should get the new extensions.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(3, len(extensions))
         self.assertTrue(42 in extensions)
         self.assertTrue(43 in extensions)
@@ -352,14 +353,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'x'), ExtensionPoint(List, 'y')]
+                return [ExtensionPoint(List, "x"), ExtensionPoint(List, "y")]
 
             def get_extensions(self, extension_point):
                 """ Return the provider's contributions to an extension point.
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     return [42]
 
                 else:
@@ -371,7 +372,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
                 """ Static trait change handler. """
 
                 self._fire_extension_point_changed(
-                    'x', event.added, event.removed, event.index
+                    "x", event.added, event.removed, event.index
                 )
 
         class ProviderB(ExtensionProvider):
@@ -382,7 +383,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     extensions = [43, 44]
 
                 else:
@@ -397,7 +398,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.add_provider(b)
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(3, len(extensions))
         self.assertTrue(42 in extensions)
         self.assertTrue(43 in extensions)
@@ -412,18 +413,18 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             listener.added = event.added
             listener.removed = event.removed
 
-        registry.add_extension_point_listener(listener, 'x')
+        registry.add_extension_point_listener(listener, "x")
 
         # Remove one of the providers.
         registry.remove_provider(b)
 
         # Make sure the listener got called.
-        self.assertEqual('x', listener.extension_point)
+        self.assertEqual("x", listener.extension_point)
         self.assertEqual([], listener.added)
         self.assertEqual([43, 44], listener.removed)
 
         # Make sure we don't get the removed extensions.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(1, len(extensions))
         self.assertTrue(42 in extensions)
 
@@ -431,14 +432,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.remove_provider(a)
 
         # Make sure the extension point is gone.
-        self.assertEqual(None, registry.get_extension_point('x'))
+        self.assertEqual(None, registry.get_extension_point("x"))
 
         # Make sure we don't get the removed extensions.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(0, len(extensions))
 
         # Make sure the listener got called.
-        self.assertEqual('x', listener.extension_point)
+        self.assertEqual("x", listener.extension_point)
         self.assertEqual([], listener.added)
         self.assertEqual([42], listener.removed)
 
@@ -454,7 +455,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'x'), ExtensionPoint(List, 'y')]
+                return [ExtensionPoint(List, "x"), ExtensionPoint(List, "y")]
 
             def get_extensions(self, extension_point):
                 """ Return the provider's contributions to an extension point.
@@ -468,7 +469,7 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.add_provider(a)
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(0, len(extensions))
 
         # Add an extension listener to the registry.
@@ -480,21 +481,21 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             listener.added = event.added
             listener.removed = event.removed
 
-        registry.add_extension_point_listener(listener, 'x')
+        registry.add_extension_point_listener(listener, "x")
 
         # Remove the provider that declared the extension point.
         registry.remove_provider(a)
 
         # Make sure the extension point is gone.
-        self.assertEqual(None, registry.get_extension_point('x'))
+        self.assertEqual(None, registry.get_extension_point("x"))
 
         # Make sure we don't get the removed extensions.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(0, len(extensions))
 
         # Make sure the listener did not get called  (since the provider did
         # not make any contributions anyway!).
-        self.assertEqual(None, getattr(listener, 'registry', None))
+        self.assertEqual(None, getattr(listener, "registry", None))
 
     def test_remove_non_existent_provider(self):
         """ remove provider """
@@ -513,15 +514,13 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         with self.assertRaises(ValueError):
             registry.remove_provider(a)
 
-    # Overriden to test differing behavior between the provider registry and
-    # the base class.
     def test_set_extensions(self):
         """ set extensions """
 
         registry = self.registry
 
         # Add an extension *point*.
-        registry.add_extension_point(self._create_extension_point('my.ep'))
+        registry.add_extension_point(self.create_extension_point("my.ep"))
 
         # Set some extensions.
         with self.assertRaises(SystemError):
@@ -539,14 +538,14 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
             def get_extension_points(self):
                 """ Return the extension points offered by the provider. """
 
-                return [ExtensionPoint(List, 'x')]
+                return [ExtensionPoint(List, "x")]
 
             def get_extensions(self, extension_point):
                 """ Return the provider's contributions to an extension point.
 
                 """
 
-                if extension_point == 'x':
+                if extension_point == "x":
                     extensions = [42, 43]
 
                 else:
@@ -558,21 +557,21 @@ class ProviderExtensionRegistryTestCase(ExtensionRegistryTestCase):
         registry.add_provider(ProviderA())
 
         # The provider's extensions should now be in the registry.
-        extensions = registry.get_extensions('x')
+        extensions = registry.get_extensions("x")
         self.assertEqual(2, len(extensions))
         self.assertEqual(list(range(42, 44)), extensions)
 
         # Make sure there's one and only one extension point.
         extension_points = registry.get_extension_points()
         self.assertEqual(1, len(extension_points))
-        self.assertEqual('x', extension_points[0].id)
+        self.assertEqual("x", extension_points[0].id)
 
         # Remove the extension point.
-        registry.remove_extension_point('x')
+        registry.remove_extension_point("x")
 
         # Make sure there are no extension points.
         extension_points = registry.get_extension_points()
         self.assertEqual(0, len(extension_points))
 
         # And that the extensions are gone too.
-        self.assertEqual([], registry.get_extensions('x'))
+        self.assertEqual([], registry.get_extensions("x"))
