@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The *definition* of a group in a tool bar or menu. """
 
@@ -37,8 +38,6 @@ class Group(Location):
     def __str__(self):
         """ Return the 'informal' string representation of the object. """
 
-        return 'Group(%s)' % self.id
+        return "Group(%s)" % self.id
 
     __repr__ = __str__
-
-#### EOF ######################################################################
