@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The *definition* of a menu in a menu bar or menu. """
 
@@ -14,7 +15,6 @@ from traits.api import Instance, List, Str
 # Local imports.
 from .group import Group
 from .location import Location
-from ..._compat import STRING_BASE_CLASS
 
 
 class CGroup(Instance):
@@ -32,9 +32,7 @@ class CGroup(Instance):
     def __init__(self, **kw):
         """ Constructor. """
 
-        super(CGroup, self).__init__(klass=Group, **kw)
-
-        return
+        super().__init__(klass=Group, **kw)
 
     ###########################################################################
     # 'TraitType' interface.
@@ -43,10 +41,10 @@ class CGroup(Instance):
     def validate(self, object, name, value):
         """ Validate a value. """
 
-        if isinstance(value, STRING_BASE_CLASS):
+        if isinstance(value, str):
             value = Group(id=value)
 
-        return super(CGroup, self).validate(object, name, value)
+        return super().validate(object, name, value)
 
 
 class Menu(Location):
@@ -73,7 +71,7 @@ class Menu(Location):
     def __str__(self):
         """ Return the 'informal' string representation of the object. """
 
-        return 'Menu(%s)' % self.name
+        return "Menu(%s)" % self.name
 
     __repr__ = __str__
 
@@ -84,6 +82,4 @@ class Menu(Location):
     def _id_default(self):
         """ Trait initializer. """
 
-        return self.name.strip('&')
-
-#### EOF ######################################################################
+        return self.name.strip("&")
