@@ -1,20 +1,18 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 
 # Enthought library imports.
 from pyface.action.api import ActionItem, Group
 from pyface.tasks.api import TaskWindowLayout
 from pyface.tasks.action.api import TaskAction
-from traits.api import List, Str
-
-# Local imports
-from envisage._compat import unicode_str
+from traits.api import List, observe, Str
 
 
 class TaskWindowLaunchAction(TaskAction):
@@ -40,11 +38,13 @@ class TaskWindowLaunchAction(TaskAction):
 
     #### Trait change handlers ################################################
 
-    def _task_changed(self, task):
+    @observe("task")
+    def _update_name(self, event):
         """ Name the action (unless a name has already been assigned).
         """
+        task = event.new
         if task and not self.name:
-            name = unicode_str()
+            name = ""
             for factory in task.window.application.task_factories:
                 if factory.id == self.task_id:
                     name = factory.name
@@ -58,7 +58,7 @@ class TaskWindowLaunchGroup(Group):
 
     #### 'Group' interface ####################################################
 
-    id = 'TaskWindowLaunchGroup'
+    id = "TaskWindowLaunchGroup"
     items = List
 
     ###########################################################################
