@@ -1,13 +1,14 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 # Enthought library imports.
-from traits.api import HasTraits, Str, Unicode
+from traits.api import HasTraits, Str
 
 
 class PreferencesCategory(HasTraits):
@@ -18,7 +19,7 @@ class PreferencesCategory(HasTraits):
     id = Str
 
     # The user-visible name of the category.
-    name = Unicode
+    name = Str
 
     # The category appears after the category with this ID.
     before = Str
