@@ -1,107 +1,145 @@
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 # Standard library imports.
-import cPickle
 import logging
+import pickle
 import os.path
 
 # Enthought library imports.
 from envisage.api import Application, ExtensionPoint
-from pyface.api import GUI, SplashScreen
-from pyface.image_resource import ImageResource
-from pyface.tasks.api import TaskLayout, TaskWindowLayout
-from traits.api import Bool, Callable, Directory, Event, HasStrictTraits, \
-     Instance, Int, List, Property, Str, Unicode, Vetoable
+from traits.api import (
+    Bool,
+    Callable,
+    Directory,
+    Event,
+    HasStrictTraits,
+    Instance,
+    Int,
+    List,
+    Str,
+    Vetoable,
+)
 from traits.etsconfig.api import ETSConfig
 
-# Local imports
-from task_window import TaskWindow
-from task_window_event import TaskWindowEvent, VetoableTaskWindowEvent
 
 # Logging.
 logger = logging.getLogger(__name__)
 
+#: Default filename for saving layout information
+DEFAULT_STATE_FILENAME = "application_memento"
+
 
 class TasksApplication(Application):
-    """ The entry point for an Envisage Tasks application.
+    """The entry point for an Envisage Tasks application.
+
+    This class handles the common case for Tasks applications and is
+    intended to be subclassed to modify its start/stop behavior, etc.
 
-    This class handles the common case for Tasks applications and is intended to
-    be subclassed to modify its start/stop behavior, etc.
     """
 
-    # Extension point IDs.
-    TASK_FACTORIES  = 'envisage.ui.tasks.tasks'
-    TASK_EXTENSIONS = 'envisage.ui.tasks.task_extensions'
+    #: Extension point ID for task factories
+    TASK_FACTORIES = "envisage.ui.tasks.tasks"
+
+    #: Extension point ID for task extensions
+    TASK_EXTENSIONS = "envisage.ui.tasks.task_extensions"
+
+    #: Pickle protocol to use for persisting layout information.
+    layout_save_protocol = Int(4)
 
     #### 'TasksApplication' interface #########################################
 
-    # The active task window (the last one to get focus).
-    active_window = Instance(TaskWindow)
+    #: The active task window (the last one to get focus).
+    active_window = Instance("envisage.ui.tasks.task_window.TaskWindow")
 
-    # The PyFace GUI for the application.
-    gui = Instance(GUI)
+    #: The Pyface GUI for the application.
+    gui = Instance("pyface.i_gui.IGUI")
 
-    # Icon for the whole application. Will be used to override all taskWindows 
-    # icons to have the same.
-    icon = Instance(ImageResource, allow_none=True) #Any
+    #: Icon for the whole application. Will be used to override all taskWindows
+    #: icons to have the same.
+    icon = Instance("pyface.image_resource.ImageResource", allow_none=True)
 
-    # The name of the application (also used on window title bars).
-    name = Unicode
+    #: The name of the application (also used on window title bars).
+    name = Str
 
-    # The splash screen for the application. By default, there is no splash
-    # screen.
-    splash_screen = Instance(SplashScreen)
+    #: The splash screen for the application. By default, there is no splash
+    #: screen.
+    splash_screen = Instance("pyface.splash_screen.SplashScreen")
 
-    # The directory on the local file system used to persist window layout
-    # information.
+    #: The directory on the local file system used to persist window layout
+    #: information.
     state_location = Directory
 
-    # Contributed task factories. This attribute is primarily for run-time
-    # inspection; to instantiate a task, use the 'create_task' method.
+    #: The filename that the application uses to persist window layout
+    #: information.
+    state_filename = Str(DEFAULT_STATE_FILENAME)
+
+    #: Contributed task factories. This attribute is primarily for run-time
+    #: inspection; to instantiate a task, use the 'create_task' method.
     task_factories = ExtensionPoint(id=TASK_FACTORIES)
 
-    # Contributed task extensions.
+    #: Contributed task extensions.
     task_extensions = ExtensionPoint(id=TASK_EXTENSIONS)
 
-    # The list of task windows created by the application.
-    windows = List(TaskWindow)
+    #: The list of task windows created by the application.
+    windows = List(Instance("envisage.ui.tasks.task_window.TaskWindow"))
 
-    # The factory for creating task windows.
-    window_factory = Callable(TaskWindow)
+    #: The factory for creating task windows.
+    window_factory = Callable
 
     #### Application layout ###################################################
 
-    # The default layout for the application. If not specified, a single window
-    # will be created with the first available task factory.
-    default_layout = List(TaskWindowLayout)
+    #: The default layout for the application. If not specified, a single
+    #: window will be created with the first available task factory.
+    default_layout = List(
+        Instance("pyface.tasks.task_window_layout.TaskWindowLayout")
+    )
 
-    # Whether to always apply the default *application level* layout when the
-    # application is started. Even if this is False, the layout state of
-    # individual tasks will be restored.
+    #: Whether to always apply the default *application level* layout when the
+    #: application is started. Even if this is True, the layout state of
+    #: individual tasks will be restored.
     always_use_default_layout = Bool(False)
 
     #### Application lifecycle events #########################################
 
-    # Fired after the initial windows have been created and the GUI event loop
-    # has been started.
+    #: Fired after the initial windows have been created and the GUI event loop
+    #: has been started.
     application_initialized = Event
 
-    # Fired immediately before the extant windows are destroyed and the GUI
-    # event loop is terminated.
+    #: Fired immediately before the extant windows are destroyed and the GUI
+    #: event loop is terminated.
     application_exiting = Event
 
-    # Fired when a task window has been created.
-    window_created = Event(TaskWindowEvent)
+    #: Fired when a task window has been created.
+    window_created = Event(
+        Instance("envisage.ui.tasks.task_window_event.TaskWindowEvent")
+    )
 
-    # Fired when a task window is opening.
-    window_opening = Event(VetoableTaskWindowEvent)
+    #: Fired when a task window is opening.
+    window_opening = Event(
+        Instance("envisage.ui.tasks.task_window_event.VetoableTaskWindowEvent")
+    )
 
-    # Fired when a task window has been opened.
-    window_opened = Event(TaskWindowEvent)
+    #: Fired when a task window has been opened.
+    window_opened = Event(
+        Instance("envisage.ui.tasks.task_window_event.TaskWindowEvent")
+    )
 
-    # Fired when a task window is closing.
-    window_closing = Event(VetoableTaskWindowEvent)
+    #: Fired when a task window is closing.
+    window_closing = Event(
+        Instance("envisage.ui.tasks.task_window_event.VetoableTaskWindowEvent")
+    )
 
-    # Fired when a task window has been closed.
-    window_closed = Event(TaskWindowEvent)
+    #: Fired when a task window has been closed.
+    window_closed = Event(
+        Instance("envisage.ui.tasks.task_window_event.TaskWindowEvent")
+    )
 
     #### Protected interface ##################################################
 
@@ -110,8 +148,9 @@ class TasksApplication(Application):
     _explicit_exit = Bool(False)
 
     # Application state.
-    _state = Instance('envisage.ui.tasks.tasks_application.'
-                      'TasksApplicationState')
+    _state = Instance(
+        "envisage.ui.tasks.tasks_application.TasksApplicationState"
+    )
 
     ###########################################################################
     # 'IApplication' interface.
@@ -120,9 +159,11 @@ class TasksApplication(Application):
     def run(self):
         """ Run the application.
 
-        Returns:
-        --------
-        Whether the application started successfully (i.e., without a veto).
+        Returns
+        -------
+        bool
+            Whether the application started successfully (i.e., without a
+            veto).
         """
         # Make sure the GUI has been created (so that, if required, the splash
         # screen is shown).
@@ -134,7 +175,7 @@ class TasksApplication(Application):
             self._create_windows()
 
             # Start the GUI event loop.
-            gui.set_trait_later(self, 'application_initialized', self)
+            gui.set_trait_later(self, "application_initialized", self)
             gui.start_event_loop()
 
         return started
@@ -146,9 +187,10 @@ class TasksApplication(Application):
     def create_task(self, id):
         """ Creates the Task with the specified ID.
 
-        Returns:
-        --------
-        The new Task, or None if there is not a suitable TaskFactory.
+        Returns
+        -------
+        pyface.tasks.task.Task
+            The new Task, or None if there is not a suitable TaskFactory.
         """
         # Get the factory for the task.
         factory = self._get_task_factory(id)
@@ -156,43 +198,52 @@ class TasksApplication(Application):
             return None
 
         # Create the task using suitable task extensions.
-        extensions = [ ext for ext in self.task_extensions
-                       if ext.task_id == id or not ext.task_id ]
+        extensions = [
+            ext
+            for ext in self.task_extensions
+            if ext.task_id == id or not ext.task_id
+        ]
         task = factory.create_with_extensions(extensions)
         task.id = factory.id
         return task
 
     def create_window(self, layout=None, restore=True, **traits):
-        """ Creates a new TaskWindow, possibly with some Tasks.
+        """Creates a new TaskWindow, possibly with some Tasks.
 
-        Parameters:
-        -----------
+        Parameters
+        ----------
         layout : TaskWindowLayout, optional
-             The layout to use for the window. The tasks described in the layout
-             will be created and added to the window automatically. If not
-             specified, the window will contain no tasks.
+             The layout to use for the window. The tasks described in
+             the layout will be created and added to the window
+             automatically. If not specified, the window will contain
+             no tasks.
 
         restore : bool, optional (default True)
-             If set, the application will restore old size and positions for the
-             window and its panes, if possible. If a layout is not provided,
-             this parameter has no effect.
+             If set, the application will restore old size and
+             positions for the window and its panes, if possible. If a
+             layout is not provided, this parameter has no effect.
 
         **traits : dict, optional
-             Additional parameters to pass to ``window_factory()`` when creating
-             the TaskWindow.
+             Additional parameters to pass to ``window_factory()``
+             when creating the TaskWindow.
+
+        Returns
+        -------
+        envisage.ui.tasks.task_window.TaskWindow
+            The new TaskWindow.
 
-        Returns:
-        --------
-        The new TaskWindow.
         """
+        from .task_window_event import TaskWindowEvent
+        from pyface.tasks.task_window_layout import TaskWindowLayout
+
         window = self.window_factory(application=self, **traits)
 
         # Listen for the window events.
-        window.on_trait_change(self._on_window_activated, 'activated')
-        window.on_trait_change(self._on_window_opening, 'opening')
-        window.on_trait_change(self._on_window_opened, 'opened')
-        window.on_trait_change(self._on_window_closing, 'closing')
-        window.on_trait_change(self._on_window_closed, 'closed')
+        window.on_trait_change(self._on_window_activated, "activated")
+        window.on_trait_change(self._on_window_opening, "opening")
+        window.on_trait_change(self._on_window_opened, "opened")
+        window.on_trait_change(self._on_window_closing, "closing")
+        window.on_trait_change(self._on_window_closed, "closed")
 
         # Event notification.
         self.window_created = TaskWindowEvent(window=window)
@@ -204,37 +255,46 @@ class TasksApplication(Application):
                 if task:
                     window.add_task(task)
                 else:
-                    logger.error('Missing factory for task with ID %r', task_id)
+                    logger.error(
+                        "Missing factory for task with ID %r", task_id
+                    )
 
             # Apply a suitable layout.
             if restore:
                 layout = self._restore_layout_from_state(layout)
-            window.set_window_layout(layout)
+        else:
+            # Create an empty layout to set default size and position only
+            layout = TaskWindowLayout()
+
+        window.set_window_layout(layout)
 
         return window
 
     def exit(self, force=False):
-        """ Exits the application, closing all open task windows.
+        """Exits the application, closing all open task windows.
 
         Each window is sent a veto-able closing event. If any window vetoes the
         close request, no window will be closed. Otherwise, all windows will be
         closed and the GUI event loop will terminate.
 
-        This method is not called when the user clicks the close button on a
-        window or otherwise closes a window through his or her window
-        manager. It is only called via the File->Exit menu item. It can also, of
-        course, be called programatically.
+        This method is not called when the user clicks the close
+        button on a window or otherwise closes a window through his or
+        her window manager. It is only called via the File->Exit menu
+        item. It can also, of course, be called programatically.
 
-        Parameters:
-        -----------
+        Parameters
+        ----------
         force : bool, optional (default False)
-            If set, windows will receive no closing events and will be destroyed
-            unconditionally. This can be useful for reliably tearing down
-            regression tests, but should be used with caution.
+            If set, windows will receive no closing events and will be
+            destroyed unconditionally. This can be useful for reliably
+            tearing down regression tests, but should be used with
+            caution.
+
+        Returns
+        -------
+        bool
+            A boolean indicating whether the application exited.
 
-        Returns:
-        --------
-        A boolean indicating whether the application exited.
         """
         self._explicit_exit = True
         try:
@@ -262,8 +322,10 @@ class TasksApplication(Application):
         """
         # Build a list of TaskWindowLayouts.
         self._load_state()
-        if self.always_use_default_layout or \
-               not self._state.previous_window_layouts:
+        if (
+            self.always_use_default_layout
+            or not self._state.previous_window_layouts
+        ):
             window_layouts = self.default_layout
         else:
             # Choose the stored TaskWindowLayouts, but only if all the task IDs
@@ -272,9 +334,11 @@ class TasksApplication(Application):
             for layout in window_layouts:
                 for task_id in layout.get_tasks():
                     if not self._get_task_factory(task_id):
-                        logger.warning('Saved application layout references '
-                                       'non-existent task %r. Falling back to '
-                                       'default application layout.' % task_id)
+                        logger.warning(
+                            "Saved application layout references "
+                            "non-existent task %r. Falling back to "
+                            "default application layout." % task_id
+                        )
                         window_layouts = self.default_layout
                         break
                 else:
@@ -283,8 +347,10 @@ class TasksApplication(Application):
 
         # Create a TaskWindow for each TaskWindowLayout.
         for window_layout in window_layouts:
-            window = self.create_window(window_layout,
-                                        restore=self.always_use_default_layout)
+            if self.always_use_default_layout:
+                window = self.create_window(window_layout, restore=False)
+            else:
+                window = self.create_window(window_layout, restore=True)
             window.open()
 
     def _get_task_factory(self, id):
@@ -306,20 +372,30 @@ class TasksApplication(Application):
         """ Loads saved application state, if possible.
         """
         state = TasksApplicationState()
-        filename = os.path.join(self.state_location, 'application_memento')
+        filename = os.path.join(self.state_location, self.state_filename)
         if os.path.exists(filename):
             # Attempt to unpickle the saved application state.
+            logger.debug("Loading application state from %s", filename)
             try:
-                with open(filename, 'r') as f:
-                    restored_state = cPickle.load(f)
+                with open(filename, "rb") as f:
+                    restored_state = pickle.load(f)
+            except Exception:
+                # If anything goes wrong, log the error and continue.
+                logger.exception("Error while restoring application state")
+            else:
                 if state.version == restored_state.version:
                     state = restored_state
+                    logger.debug("Application state successfully restored")
                 else:
-                    logger.warn('Discarding outdated application layout')
-            except:
-                # If anything goes wrong, log the error and continue.
-                logger.exception('Restoring application layout from %s',
-                                 filename)
+                    logger.warning(
+                        "Discarding outdated application state: "
+                        "expected version %s, got version %s",
+                        state.version,
+                        restored_state.version,
+                    )
+        else:
+            logger.debug("No saved application state found at %s", filename)
+
         self._state = state
 
     def _restore_layout_from_state(self, layout):
@@ -332,12 +408,13 @@ class TasksApplication(Application):
             # ensure that it is correct.
             match.active_task = layout.get_active_task()
             layout = match
-            
-        # If that fails, at least try to restore the layout of individual tasks.
+
+        # If that fails, at least try to restore the layout of
+        # individual tasks.
         else:
             layout = layout.clone_traits()
             for i, item in enumerate(layout.items):
-                id = item if isinstance(item, basestring) else item.id
+                id = item if isinstance(item, str) else item.id
                 match = self._state.get_task_layout(id)
                 if match:
                     layout.items[i] = match
@@ -348,36 +425,49 @@ class TasksApplication(Application):
         """ Saves the application state.
         """
         # Grab the current window layouts.
-        window_layouts = [ w.get_window_layout() for w in self.windows ]
+        window_layouts = [w.get_window_layout() for w in self.windows]
         self._state.previous_window_layouts = window_layouts
 
         # Attempt to pickle the application state.
-        filename = os.path.join(self.state_location, 'application_memento')
+        filename = os.path.join(self.state_location, self.state_filename)
+        logger.debug("Saving application state to %s", filename)
         try:
-            with open(filename, 'w') as f:
-                cPickle.dump(self._state, f)
-        except:
+            with open(filename, "wb") as f:
+                pickle.dump(self._state, f, protocol=self.layout_save_protocol)
+        except Exception:
             # If anything goes wrong, log the error and continue.
-            logger.exception('Saving application layout')
+            logger.exception("Error while saving application state")
+        else:
+            logger.debug("Application state successfully saved")
 
     #### Trait initializers ###################################################
 
+    def _window_factory_default(self):
+        from envisage.ui.tasks.task_window import TaskWindow
+
+        return TaskWindow
+
     def _default_layout_default(self):
+        from pyface.tasks.task_window_layout import TaskWindowLayout
+
         window_layout = TaskWindowLayout()
         if self.task_factories:
-            window_layout.items = [ self.task_factories[0].id ]
-        return [ window_layout ]
+            window_layout.items = [self.task_factories[0].id]
+        return [window_layout]
 
     def _gui_default(self):
+        from pyface.gui import GUI
+
         return GUI(splash_screen=self.splash_screen)
 
     def _state_location_default(self):
-        state_location = os.path.join(ETSConfig.application_home,
-                                      'tasks', ETSConfig.toolkit)
+        state_location = os.path.join(
+            ETSConfig.application_home, "tasks", ETSConfig.toolkit
+        )
         if not os.path.exists(state_location):
             os.makedirs(state_location)
 
-        logger.debug('Tasks state location is %s', state_location)
+        logger.debug("Tasks state location is %s", state_location)
 
         return state_location
 
@@ -387,23 +477,31 @@ class TasksApplication(Application):
         self.active_window = window
 
     def _on_window_opening(self, window, trait_name, event):
+        from .task_window_event import VetoableTaskWindowEvent
+
         # Event notification.
         self.window_opening = window_event = VetoableTaskWindowEvent(
-            window=window)
+            window=window
+        )
 
         if window_event.veto:
             event.veto = True
 
     def _on_window_opened(self, window, trait_name, event):
+        from .task_window_event import TaskWindowEvent
+
         self.windows.append(window)
 
         # Event notification.
         self.window_opened = TaskWindowEvent(window=window)
 
     def _on_window_closing(self, window, trait_name, event):
+        from .task_window_event import VetoableTaskWindowEvent
+
         # Event notification.
         self.window_closing = window_event = VetoableTaskWindowEvent(
-            window=window)
+            window=window
+        )
 
         if window_event.veto:
             event.veto = True
@@ -418,6 +516,8 @@ class TasksApplication(Application):
                 self._prepare_exit()
 
     def _on_window_closed(self, window, trait_name, event):
+        from .task_window_event import TaskWindowEvent
+
         self.windows.remove(window)
 
         # Event notification.
@@ -425,9 +525,7 @@ class TasksApplication(Application):
 
         # Was this the last window?
         if len(self.windows) == 0:
-            # Invoke later to ensure that 'closed' event handlers get called
-            # before 'stop()' does.
-            self.gui.invoke_later(self.stop)
+            self.stop()
 
 
 class TasksApplicationState(HasStrictTraits):
@@ -435,13 +533,17 @@ class TasksApplicationState(HasStrictTraits):
         application state.
     """
 
-    # TaskWindowLayouts for the windows extant at application exit. Only used if
-    # 'always_use_default_layout' is disabled.
-    previous_window_layouts = List(TaskWindowLayout)
+    # TaskWindowLayouts for the windows extant at application
+    # exit. Only used if 'always_use_default_layout' is disabled.
+    previous_window_layouts = List(
+        Instance("pyface.tasks.task_window_layout.TaskWindowLayout")
+    )
 
     # A list of TaskWindowLayouts accumulated throughout the application's
     # lifecycle.
-    window_layouts = List(TaskWindowLayout)
+    window_layouts = List(
+        Instance("pyface.tasks.task_window_layout.TaskWindowLayout")
+    )
 
     # The "version" for the state data. This should be incremented whenever a
     # backwards incompatible change is made to this class or any of the layout
@@ -468,6 +570,9 @@ class TasksApplicationState(HasStrictTraits):
     def push_window_layout(self, window_layout):
         """ Merge a TaskWindowLayout into the accumulated list.
         """
-        self.window_layouts = [ layout for layout in self.window_layouts
-                                if not layout.is_equivalent_to(window_layout) ]
+        self.window_layouts = [
+            layout
+            for layout in self.window_layouts
+            if not layout.is_equivalent_to(window_layout)
+        ]
         self.window_layouts.insert(0, window_layout)
