@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 # Enthought library imports.
 from envisage.api import ExtensionPoint, Plugin, ServiceOffer
@@ -14,7 +15,7 @@ from traits.api import Callable, Instance, List
 from .preferences_category import PreferencesCategory
 
 # Constants.
-PKG = '.'.join(__name__.split('.')[:-1])
+PKG = ".".join(__name__.split(".")[:-1])
 
 
 class TasksPlugin(Plugin):
@@ -25,21 +26,21 @@ class TasksPlugin(Plugin):
     """
 
     # The IDs of the extension point that this plugin offers.
-    PREFERENCES_CATEGORIES = PKG + '.preferences_categories'
-    PREFERENCES_PANES = PKG + '.preferences_panes'
-    TASKS = PKG + '.tasks'
-    TASK_EXTENSIONS = PKG + '.task_extensions'
+    PREFERENCES_CATEGORIES = PKG + ".preferences_categories"
+    PREFERENCES_PANES = PKG + ".preferences_panes"
+    TASKS = PKG + ".tasks"
+    TASK_EXTENSIONS = PKG + ".task_extensions"
 
     # The IDs of the extension points that this plugin contributes to.
-    SERVICE_OFFERS = 'envisage.service_offers'
+    SERVICE_OFFERS = "envisage.service_offers"
 
     #### 'IPlugin' interface ##################################################
 
     #: The plugin's unique identifier.
-    id = 'envisage.ui.tasks'
+    id = "envisage.ui.tasks"
 
     #: The plugin's name (suitable for displaying to the user).
-    name = 'Tasks'
+    name = "Tasks"
 
     #### Extension points offered by this plugin ##############################
 
@@ -48,19 +49,24 @@ class TasksPlugin(Plugin):
     #: will be created automatically if necessary; this extension point is
     #: useful when ensuring that a category is inserted at a specific location.
     preferences_categories = ExtensionPoint(
-        List(PreferencesCategory), id=PREFERENCES_CATEGORIES, desc="""
+        List(PreferencesCategory),
+        id=PREFERENCES_CATEGORIES,
+        desc="""
 
         This extension point makes preference categories available to the
         application. Note that preference categories will be created
         automatically if necessary; this extension point is useful when one
         wants to ensure that a category is inserted at a specific location.
-        """)
+        """,
+    )
 
     #: Contributed preference pane factories. Each contribution to this
     #: extension point must be a callable with the signature
     #: ``callable(**traits) -> PreferencePane``.
     preferences_panes = ExtensionPoint(
-        List(Callable), id=PREFERENCES_PANES, desc="""
+        List(Callable),
+        id=PREFERENCES_PANES,
+        desc="""
 
         A preferences pane appears in the preferences dialog to allow the user
         manipulate certain preference values.
@@ -73,12 +79,13 @@ class TasksPlugin(Plugin):
 
         The easiest way to contribute such a factory is to create a class
         that derives from 'envisage.ui.tasks.api.PreferencesPane'.
-        """)
+        """,
+    )
 
     #: Contributed task factories. Contributions to this extension point
     #: must have type ``TaskFactory``.
     tasks = ExtensionPoint(
-        List(Instance('envisage.ui.tasks.task_factory.TaskFactory')),
+        List(Instance("envisage.ui.tasks.task_factory.TaskFactory")),
         id=TASKS,
         desc="""
 
@@ -86,12 +93,13 @@ class TasksPlugin(Plugin):
 
         Each contribution to the extension point must be an instance of
         'envisage.tasks.api.TaskFactory.
-        """)
+        """,
+    )
 
     #: Contributed task extensions. Contributions to this extension point
     #: must have type ``TaskExtension``.
     task_extensions = ExtensionPoint(
-        List(Instance('envisage.ui.tasks.task_extension.TaskExtension')),
+        List(Instance("envisage.ui.tasks.task_extension.TaskExtension")),
         id=TASK_EXTENSIONS,
         desc="""
 
@@ -100,7 +108,8 @@ class TasksPlugin(Plugin):
 
         Each contribution to the extension point must be an instance of
         'envisage.tasks.api.TaskExtension'.
-        """)
+        """,
+    )
 
     #### Contributions to extension points made by this plugin ################
 
@@ -108,8 +117,9 @@ class TasksPlugin(Plugin):
 
     def _my_service_offers_default(self):
         preferences_dialog_service_offer = ServiceOffer(
-            protocol='envisage.ui.tasks.preferences_dialog.PreferencesDialog',
-            factory=self._create_preferences_dialog_service)
+            protocol="envisage.ui.tasks.preferences_dialog.PreferencesDialog",
+            factory=self._create_preferences_dialog_service,
+        )
 
         return [preferences_dialog_service_offer]
 
@@ -121,15 +131,17 @@ class TasksPlugin(Plugin):
         from .task_extension import TaskExtension
         from pyface.tasks.action.api import DockPaneToggleGroup, SchemaAddition
 
-        actions = [SchemaAddition(id='Exit',
-                                  factory=ExitAction,
-                                  path='MenuBar/File'),
-                   SchemaAddition(id='Preferences',
-                                  factory=PreferencesGroup,
-                                  path='MenuBar/Edit'),
-                   SchemaAddition(id='DockPaneToggleGroup',
-                                  factory=DockPaneToggleGroup,
-                                  path='MenuBar/View')]
+        actions = [
+            SchemaAddition(id="Exit", factory=ExitAction, path="MenuBar/File"),
+            SchemaAddition(
+                id="Preferences", factory=PreferencesGroup, path="MenuBar/Edit"
+            ),
+            SchemaAddition(
+                id="DockPaneToggleGroup",
+                factory=DockPaneToggleGroup,
+                path="MenuBar/View",
+            ),
+        ]
 
         return [TaskExtension(actions=actions)]
 
@@ -143,7 +155,10 @@ class TasksPlugin(Plugin):
         from .preferences_dialog import PreferencesDialog
 
         dialog = PreferencesDialog(application=self.application)
-        dialog.trait_set(categories=self.preferences_categories,
-                         panes=[factory(dialog=dialog)
-                                for factory in self.preferences_panes])
+        dialog.trait_set(
+            categories=self.preferences_categories,
+            panes=[
+                factory(dialog=dialog) for factory in self.preferences_panes
+            ],
+        )
         return dialog
