@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The Envisage workbench. """
 
@@ -40,7 +41,7 @@ class Workbench(pyface.Workbench):
     application = Instance(IApplication)
 
     # Should the user be prompted before exiting the workbench?
-    prompt_on_exit = Delegate('_preferences')
+    prompt_on_exit = Delegate("_preferences")
 
     #### Private interface ####################################################
 
@@ -60,7 +61,3 @@ class Workbench(pyface.Workbench):
             )
             if answer != YES:
                 event.veto = True
-
-        return
-
-#### EOF ######################################################################
