@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The entry point for an Envisage Workbench application. """
 
@@ -12,15 +13,6 @@
 # Standard library imports.
 import logging
 
-# Enthought library imports.
-#
-# fixme: The ordering of these imports is critical. We don't use traits UI in
-# this module, but it must be imported *before* any 'HasTraits' class whose
-# instances might want to have 'edit_traits' called on them.
-#
-# fixme: Just importing the package is enought (see above).
-import traitsui
-
 # Enthought library imports.
 from envisage.api import Application
 from pyface.api import AboutDialog, Dialog, GUI, ImageResource
@@ -69,10 +61,10 @@ class WorkbenchApplication(Application):
     about_dialog = Instance(Dialog)
 
     # The icon used on window title bars etc.
-    icon = Instance(ImageResource, ImageResource('application.ico'))
+    icon = Instance(ImageResource, ImageResource("application.ico"))
 
     # The name of the application (also used on window title bars etc).
-    name = Str('Workbench')
+    name = Str("Workbench")
 
     # The splash screen (None, the default, if no splash screen is required).
     splash_screen = Instance(SplashScreen)
@@ -99,7 +91,7 @@ class WorkbenchApplication(Application):
 
         """
 
-        logger.debug('---------- workbench application ----------')
+        logger.debug("---------- workbench application ----------")
 
         # Make sure the GUI has been created (so that, if required, the splash
         # screen is shown).
@@ -114,15 +106,13 @@ class WorkbenchApplication(Application):
             window.open()
 
             # We stop the application when the workbench has exited.
-            self.workbench.on_trait_change(self._on_workbench_exited, 'exited')
+            self.workbench.on_trait_change(self._on_workbench_exited, "exited")
 
             # Start the GUI event loop.
             #
             # THIS CALL DOES NOT RETURN UNTIL THE GUI IS CLOSED.
             gui.start_event_loop()
 
-        return
-
     ###########################################################################
     # 'WorkbenchApplication' interface.
     ###########################################################################
@@ -132,7 +122,7 @@ class WorkbenchApplication(Application):
     def _about_dialog_default(self):
         """ Trait initializer. """
 
-        return AboutDialog(image=ImageResource('about'))
+        return AboutDialog(image=ImageResource("about"))
 
     def _gui_default(self):
         """ Trait initializer. """
@@ -153,14 +143,12 @@ class WorkbenchApplication(Application):
         # that it can have the active window as its parent.
         self.about_dialog.open()
 
-        return
-
     # fixme: Is this needed on the public API? Why can't we just do this in
     # the default initializer (_workbench_default)?
     def create_workbench(self):
         """ Create the workbench. """
 
-        logger.debug('workbench factory %s', self.workbench_factory)
+        logger.debug("workbench factory %s", self.workbench_factory)
 
         return self.workbench_factory(application=self)
 
@@ -173,8 +161,6 @@ class WorkbenchApplication(Application):
 
         self.workbench.exit()
 
-        return
-
     ###########################################################################
     # Private interface.
     ###########################################################################
@@ -192,7 +178,3 @@ class WorkbenchApplication(Application):
         # might mean that somebody listening for the window being closed would
         # get the event *after* the application had already stopped!
         self.gui.invoke_later(self.stop)
-
-        return
-
-#### EOF ######################################################################
